==> julia-git-hdf5_jll-src-1.14.3%2B3-2-any.pkg.tar.zst: usr/share/julia/arch-site/HDF5_jll/src/HDF5_jll.jl <==
module HDF5_jll
using Libdl
is_available() = true
find_artifact_dir() = "/usr"
artifact_dir = "/usr"
const PATH_list = String[]
const LIBPATH_list = String[]
const PATH = Ref("")
const LIBPATH = Ref("")
const LIBPATH_env = "LD_LIBRARY_PATH"
export libhdf5
const libhdf5_path = "/usr/lib/libhdf5.so.311"
libhdf5_handle = C_NULL
const libhdf5 = "libhdf5.so.311"
export libhdf5_cpp
const libhdf5_cpp_path = "/usr/lib/libhdf5_cpp.so.310"
libhdf5_cpp_handle = C_NULL
const libhdf5_cpp = "libhdf5_cpp.so.310"
export libhdf5_fortran
const libhdf5_fortran_path = "/usr/lib/libhdf5_fortran.so.311"
libhdf5_fortran_handle = C_NULL
const libhdf5_fortran = "libhdf5_fortran.so.311"
export libhdf5_hl
const libhdf5_hl_path = "/usr/lib/libhdf5_hl.so.310"
libhdf5_hl_handle = C_NULL
const libhdf5_hl = "libhdf5_hl.so.310"
export libhdf5_hl_cpp
const libhdf5_hl_cpp_path = "/usr/lib/libhdf5_hl_cpp.so.310"
libhdf5_hl_cpp_handle = C_NULL
const libhdf5_hl_cpp = "libhdf5_hl_cpp.so.310"
export libhdf5_hl_fortran
const libhdf5_hl_fortran_path = "/usr/lib/libhdf5hl_fortran.so.310"
libhdf5_hl_fortran_handle = C_NULL
const libhdf5_hl_fortran = "libhdf5hl_fortran.so.310"
export h5clear
const h5clear_path = "/usr/bin/h5clear"
h5clear(f::Function; kw...) = f(h5clear_path)
export h5copy
const h5copy_path = "/usr/bin/h5copy"
h5copy(f::Function; kw...) = f(h5copy_path)
export h5debug
const h5debug_path = "/usr/bin/h5debug"
h5debug(f::Function; kw...) = f(h5debug_path)
export h5delete
const h5delete_path = "/usr/bin/h5delete"
h5delete(f::Function; kw...) = f(h5delete_path)
export h5diff
const h5diff_path = "/usr/bin/h5diff"
h5diff(f::Function; kw...) = f(h5diff_path)
export h5dump
const h5dump_path = "/usr/bin/h5dump"
h5dump(f::Function; kw...) = f(h5dump_path)
export h5format_convert
const h5format_convert_path = "/usr/bin/h5format_convert"
h5format_convert(f::Function; kw...) = f(h5format_convert_path)
export h5import
const h5import_path = "/usr/bin/h5import"
h5import(f::Function; kw...) = f(h5import_path)
export h5jam
const h5jam_path = "/usr/bin/h5jam"
h5jam(f::Function; kw...) = f(h5jam_path)
export h5ls
const h5ls_path = "/usr/bin/h5ls"
h5ls(f::Function; kw...) = f(h5ls_path)
export h5mkgrp
const h5mkgrp_path = "/usr/bin/h5mkgrp"
h5mkgrp(f::Function; kw...) = f(h5mkgrp_path)
export h5perf_serial
const h5perf_serial_path = "/usr/bin/h5perf_serial"
h5perf_serial(f::Function; kw...) = f(h5perf_serial_path)
export h5repack
const h5repack_path = "/usr/bin/h5repack"
h5repack(f::Function; kw...) = f(h5repack_path)
export h5repart
const h5repart_path = "/usr/bin/h5repart"
h5repart(f::Function; kw...) = f(h5repart_path)
export h5stat
const h5stat_path = "/usr/bin/h5stat"
h5stat(f::Function; kw...) = f(h5stat_path)
export h5unjam
const h5unjam_path = "/usr/bin/h5unjam"
h5unjam(f::Function; kw...) = f(h5unjam_path)
export h5watch
const h5watch_path = "/usr/bin/h5watch"
h5watch(f::Function; kw...) = f(h5watch_path)
function __init__()
    global libhdf5_handle = dlopen(libhdf5_path)
    global libhdf5_cpp_handle = dlopen(libhdf5_cpp_path)
    global libhdf5_fortran_handle = dlopen(libhdf5_fortran_path)
    global libhdf5_hl_handle = dlopen(libhdf5_hl_path)
    global libhdf5_hl_cpp_handle = dlopen(libhdf5_hl_cpp_path)
    global libhdf5_hl_fortran_handle = dlopen(libhdf5_hl_fortran_path)
end
end

==> julia-git-hdf5_jll-src-1.14.6%2B0-2-any.pkg.tar.zst: usr/share/julia/arch-site/HDF5_jll/src/HDF5_jll.jl <==
module HDF5_jll
using Libdl
is_available() = true
find_artifact_dir() = "/usr"
artifact_dir = "/usr"
const PATH_list = String[]
const LIBPATH_list = String[]
const PATH = Ref("")
const LIBPATH = Ref("")
const LIBPATH_env = "LD_LIBRARY_PATH"
export libhdf5
const libhdf5_path = "/usr/lib/libhdf5.so.310"
libhdf5_handle = C_NULL
const libhdf5 = "libhdf5.so.310"
export libhdf5_cpp
const libhdf5_cpp_path = "/usr/lib/libhdf5_cpp.so.310"
libhdf5_cpp_handle = C_NULL
const libhdf5_cpp = "libhdf5_cpp.so.310"
export libhdf5_fortran
const libhdf5_fortran_path = "/usr/lib/libhdf5_fortran.so.310"
libhdf5_fortran_handle = C_NULL
const libhdf5_fortran = "libhdf5_fortran.so.310"
export libhdf5_hl
const libhdf5_hl_path = "/usr/lib/libhdf5_hl.so.310"
libhdf5_hl_handle = C_NULL
const libhdf5_hl = "libhdf5_hl.so.310"
export libhdf5_hl_cpp
const libhdf5_hl_cpp_path = "/usr/lib/libhdf5_hl_cpp.so.310"
libhdf5_hl_cpp_handle = C_NULL
const libhdf5_hl_cpp = "libhdf5_hl_cpp.so.310"
export libhdf5_hl_fortran
const libhdf5_hl_fortran_path = "/usr/lib/libhdf5_hl_fortran.so.310"
libhdf5_hl_fortran_handle = C_NULL
const libhdf5_hl_fortran = "libhdf5_hl_fortran.so.310"
export h5clear
const h5clear_path = "/usr/bin/h5clear"
h5clear(f::Function; kw...) = f(h5clear_path)
export h5copy
const h5copy_path = "/usr/bin/h5copy"
h5copy(f::Function; kw...) = f(h5copy_path)
export h5debug
const h5debug_path = "/usr/bin/h5debug"
h5debug(f::Function; kw...) = f(h5debug_path)
export h5delete
const h5delete_path = "/usr/bin/h5delete"
h5delete(f::Function; kw...) = f(h5delete_path)
export h5diff
const h5diff_path = "/usr/bin/h5diff"
h5diff(f::Function; kw...) = f(h5diff_path)
export h5dump
const h5dump_path = "/usr/bin/h5dump"
h5dump(f::Function; kw...) = f(h5dump_path)
export h5format_convert
const h5format_convert_path = "/usr/bin/h5format_convert"
h5format_convert(f::Function; kw...) = f(h5format_convert_path)
export h5import
const h5import_path = "/usr/bin/h5import"
h5import(f::Function; kw...) = f(h5import_path)
export h5jam
const h5jam_path = "/usr/bin/h5jam"
h5jam(f::Function; kw...) = f(h5jam_path)
export h5ls
const h5ls_path = "/usr/bin/h5ls"
h5ls(f::Function; kw...) = f(h5ls_path)
export h5mkgrp
const h5mkgrp_path = "/usr/bin/h5mkgrp"
h5mkgrp(f::Function; kw...) = f(h5mkgrp_path)
export h5perf_serial
const h5perf_serial_path = "/usr/bin/h5perf_serial"
h5perf_serial(f::Function; kw...) = f(h5perf_serial_path)
export h5repack
const h5repack_path = "/usr/bin/h5repack"
h5repack(f::Function; kw...) = f(h5repack_path)
export h5repart
const h5repart_path = "/usr/bin/h5repart"
h5repart(f::Function; kw...) = f(h5repart_path)
export h5stat
const h5stat_path = "/usr/bin/h5stat"
h5stat(f::Function; kw...) = f(h5stat_path)
export h5unjam
const h5unjam_path = "/usr/bin/h5unjam"
h5unjam(f::Function; kw...) = f(h5unjam_path)
export h5watch
const h5watch_path = "/usr/bin/h5watch"
h5watch(f::Function; kw...) = f(h5watch_path)
function __init__()
    global libhdf5_handle = dlopen(libhdf5_path)
    global libhdf5_cpp_handle = dlopen(libhdf5_cpp_path)
    global libhdf5_fortran_handle = dlopen(libhdf5_fortran_path)
    global libhdf5_hl_handle = dlopen(libhdf5_hl_path)
    global libhdf5_hl_cpp_handle = dlopen(libhdf5_hl_cpp_path)
    global libhdf5_hl_fortran_handle = dlopen(libhdf5_hl_fortran_path)
end
end
